@@ -9,7 +9,7 @@ from lxml import etree, html
 
 # local
 from amilib.wikimedia import WikidataPage, WikidataExtractor, WikidataProperty, WikidataFilter
-# from pyamihtmlx.ami_dict import WIKIDATA_ID, AmiEntry
+from amilib.wikimedia import WikidataLookup
 from test.resources import Resources
 from test.test_all import AmiAnyTest
 
@@ -18,20 +18,6 @@ cd pyami # toplevel checkout
 python3 -m test.test_wikidata
 """
 
-# ignoring all dictionary functionality
-try:
-    from amilib.wikimedia import WikidataLookup
-
-    # from pyamihtmlx.ami_dict import AMIDictError, AmiDictionary
-
-    logging.info(f"loaded py4ami.ami_dict")
-except Exception:
-    try:
-        from amilib.wikimedia import WikidataLookup
-        # from pyamihtmlx.ami_dict import AMIDictError
-    except Exception as e:
-        logging.error(f"Cannot import from py4ami.ami_dict")
-
 ami_dictRESOURCES_DIR = Path(Path(__file__).parent.parent, "test", "resources")
 # TEMP_DIR = Path(Path(__file__).parent.parent, "temp_oldx_delete")
 # DICTIONARY_DIR = Path(os.path.expanduser("~"), "projects", "CEVOpen", "dictionary")
@@ -39,12 +25,19 @@ EO_COMPOUND = "eoCompound"
 EO_COMPOUND_DIR = Path(Resources.TEST_RESOURCES_DIR, EO_COMPOUND)
 
 
-# NOTE some of these are lengthy (seconds) as they lookup on the Ne
+# NOTE some of these are lengthy (seconds) as they lookup on the Net
 
-class TestWikidataLookup(unittest.TestCase):
+class TestWikidataLookup_WIKI_NET(unittest.TestCase):
+    """
+    lookup wikidata terms, Ids, Requires NET
+    """
 
-    def test_lookup_wikidata_acetone(self):
-        """FAILS probablt wikidata parsing (maybe u200 need parsing out)"""
+    def test_lookup_wikidata_acetone_WIKI_NET(self):
+        """
+        Lookup single term in Wikidata
+        Needs connectivity
+        :return:
+        """
         term = "acetone"
         wikidata_lookup = WikidataLookup()
         qitem0, desc, wikidata_hits = wikidata_lookup.lookup_wikidata(term)
@@ -53,9 +46,10 @@ class TestWikidataLookup(unittest.TestCase):
         # assert wikidata_hits == ['Q49546', 'Q24634417', 'Q329022', 'Q63986955', 'Q4673277']
         assert 'Q49546' in wikidata_hits and len(wikidata_hits) >= 3
 
-    def test_lookup_chemical_compound(self):
+    def test_lookup_wiki_properties_chemical_compound_WIKI_NET(self):
         """
-        FAILS probably wikidata parsing
+        Lookup Wikidata page by Q number and confirm properties
+        :return: None
         """
         wiki_page = WikidataPage("Q49546")
         # wiki_page.debug_page()
@@ -72,42 +66,35 @@ class TestWikidataLookup(unittest.TestCase):
         qval = wiki_page.get_predicate_object("P31", "Q13442814")
         assert len(qval) == 1
 
-    def test_lookup_wikidata_bad(self):
-        """This fails if uncommented"""
-        term = "benzene"
-        wikidata_lookup = WikidataLookup()
-        qitem0, desc, wikidata_hits = wikidata_lookup.lookup_wikidata(term)
-        # assert qitem0 == "Q170304"  # dopamine???
-        # assert desc == "hormone and neurotransmitter"
-        # this needs mending as it found dopmamine (4-(2-azanylethyl)benzene-1,2-diol)
-        assert len(wikidata_hits) > 0
-        # assert wikidata_hits == ['Q170304', 'Q2270', 'Q15779', 'Q186242', 'Q28917']
-
-    @unittest.skip(reason="NET, long")
-    def test_lookup_solvents(self):
-        terms = ["acetone", "chloroform", "ethanol"]
+    def test_lookup_multiple_terms_solvents_WIKI_NET(self):
+        """
+        search multiple terms in Wikidata
+        """
+        terms = ["acetone", "chloroform"]
         wikidata_lookup = WikidataLookup()
         qitems, descs = wikidata_lookup.lookup_items(terms)
-        assert qitems == ['Q49546', 'Q172275', 'Q153']
-        assert descs == ['chemical compound', 'chemical compound', 'chemical compound']
+        assert qitems == ['Q49546', 'Q172275']
+        assert descs == ['chemical compound', 'chemical compound']
 
-    @unittest.skip(reason="Net, Long")
-    def test_lookup_parkinsons(self):
+    @unittest.skip(reason="No AMI Dict in library")
+    def test_lookup_with_ami_dictionary_WIKI_NET_DICT(self):
+        """
+        Wikidata Lookup of items in AMIDict
+        TODO add AmiDict to amilib
+        :return:
+        """
         terms = [
-            "SCRNASeq",
-            "SNPS",
             "A53T",
             "linkage disequilibrium",
-            "Parkinsons",
             "transcriptomics"
         ]
         wikidata_lookup = WikidataLookup()
         # qitems, descs = wikidata_lookup.lookup_items(terms)
         temp_dir = Path(AmiAnyTest.TEMP_DIR, "wikidata", "oldx")
         temp_dir.mkdir(exist_ok=True, parents=True)
-        # dictfile, amidict = AMIDict.create_from_list_of_strings_and_write_to_file(terms, title="parkinsons",
-        #                                                                           wikidata=True, directory=temp_dir)
-        # assert os.path.exists(dictfile)
+        dictfile, amidict = AMIDict.create_from_list_of_strings_and_write_to_file(
+            terms, title="parkinsons", wikidata=True, directory=temp_dir)
+        assert Path(dictfile).exists()
 
     def test_parse_wikidata_html(self):
         """find Wikidata items with given property
@@ -209,13 +196,16 @@ class TestWikidataLookup(unittest.TestCase):
         assert len(qvals) == 1
         assert qvals[0].text == 'chemical compound'
 
-    @unittest.skip(f"constructor for WikidataPage needs adjusting")
     def test_get_wikidata_predicate_value(self):
-        """searches for instance-of (P31) chemical_compound (Q11173) in a wikidata page"""
+        """searches for instance-of (P31) chemical_compound (Q11173) in a wikidata page
+        TODO allow for reading local files directly
+        """
         pred_id = "P31"
         obj_id = "Q11173"
         file = str(Path(EO_COMPOUND_DIR, "q407418.html"))
-        qval = WikidataPage(file).get_predicate_object(pred_id, obj_id)
+        page = WikidataPage.create_wikidata_ppage_from_file(file)
+        assert page is not None
+        qval = page.get_predicate_object(pred_id, obj_id)
         assert qval[0].text == 'chemical compound'
 
     def test_get_title_of_page(self):
@@ -236,14 +226,16 @@ class TestWikidataLookup(unittest.TestCase):
         <th scope="col" class="wikibase-entitytermsforlanguagelistview-cell wikibase-entitytermsforlanguagelistview-language">Language</th>
 
         """
-        language_elems = WikidataPage("q407418").get_elements_for_attval_containing_word("class",
-                                                                                         "wikibase-entitytermsforlanguagelistview-language")
+        language_elems = WikidataPage("q407418").get_elements_for_attval_containing_word(
+            "class",
+            "wikibase-entitytermsforlanguagelistview-language")
         assert len(language_elems) == 1
         assert language_elems[0].text == 'Language'
 
-    @unittest.skip("bug is object/ids, needs fixing")
+    @unittest.skip("bug is comparison of sets, needs fixing")
     def test_find_left_properties_and_statements(self):
         """
+        TODO comparison of retrieved properties
             <div class="wikibase-snaklistview">
                 <div class="wikibase-snaklistview-listview">
                     <div class="wikibase-snakview wikibase-snakview-755d14b02a41025911e80439cb6ed31dcc966768">
@@ -353,18 +345,18 @@ class TestWikidataLookup(unittest.TestCase):
         print(f" data properties {data_property_list}")
         property_set = set(data_property_list)
         print(f"set {property_set}")
-        assert 78 >= len(property_set) >= 70
-        expected = {[
-            'P31', 'P279', 'P361', 'P117', 'P8224', 'P2067', 'P274', 'P233', 'P2017', 'P2054']}
+        assert 100 >= len(property_set) >= 70
+        expected = set([
+            'P31', 'P279', 'P361', 'P117', 'P8224', 'P2067', 'P274', 'P233', 'P2017', 'P2054'])
         difference = expected.symmetric_difference(property_set)
         print(f"diff {len(difference)} {difference}")
-        assert expected.issubset(property_set)
+        assert expected.issubset(property_set), f"not found in {property_set}"
         assert set(wikidata_page.get_property_id_list()[:10]).difference(expected) == set()
         assert wikidata_page.get_property_name_list()[:10] == [
             'instance of', 'subclass of', 'part of', 'chemical structure', 'molecular model or crystal lattice model',
             'mass', 'chemical formula', 'canonical SMILES', 'isomeric SMILES', 'density']
         property_list = wikidata_page.get_data_property_list()
-        assert 78 >= len(property_list) >= 70
+        assert 108 >= len(property_list) >= 70
         # assert wikidata_page.get_property_id_list()[:10] == [
         #     'P31', 'P279', 'P361', 'P117', 'P8224', 'P2067', 'P274', 'P233', 'P2017', 'P2054']
         assert 'P31' in wikidata_page.get_property_id_list()
@@ -660,5 +652,27 @@ class TestWikidataLookup(unittest.TestCase):
                    'regex'] == "(chemical compound|chemical element)", f"found {filter.json['filter']['regex']}"
 
 
+class WikimediaTests:
+    @classmethod
+    def test_sparql_wrapper_WIKI(cls):
+        """A
+        uthor Shweata M Hegde
+        from wikidata query site
+        """
+
+        query = """#research council
+        SELECT ?researchcouncil ?researchcouncilLabel 
+        WHERE 
+        {
+          ?researchcouncil wdt:P31 wd:Q10498148.
+          SERVICE wikibase:label_xml { bd:serviceParam wikibase:language "[AUTO_LANGUAGE],en". }
+        }"""
+
+        results = WS.get_results_xml(query)
+        print(results)
+
+
+
+
 if __name__ == '__main__':
     unittest.main()
